package com.jiuqi.util;

import java.util.Iterator;
import java.util.HashMap;
import java.text.DecimalFormat;

public class Html
{
    private static final String[] SYS_COLOR_NAMES;
    private static final int SYS_COLOR_MASK = -16777216;
    
    static {
        SYS_COLOR_NAMES = new String[] { "scrollbar", "background", "activecaption", "inactivecaption", "menu", "window", "windowframe", "menutext", "windowtext", "captiontext", "inactiveborder", "inactivecaption", "appworkspace", "highlight", "highlighttext", "buttonface", "buttonshadow", "graytext", "buttontext", "inactivecaption", "buttonhighlight", "threeddarkshadow", "threedhighlight", "infotext", "infobackground" };
    }
    
    private Html() {
    }
    
    public static String getHtmlColor(final int colorValue) {
        String returnStr = "";
        if (colorValue < 0) {
            returnStr = getSystemColor(colorValue);
        }
        else {
            returnStr = "#" + repairLength(Integer.toHexString(BGR2RGB(colorValue)));
        }
        return returnStr;
    }
    
    public static int BGR2RGB(final int color) {
        if (color < 0) {
            return color;
        }
        final int red = (color & 0xFF) << 16;
        final int blue = (color & 0xFF0000) >> 16;
        final int green = color & 0xFF00;
        return red | blue | green;
    }
    
    private static String repairLength(final String colorStr) {
        if (colorStr == null) {
            return "000000";
        }
        if (colorStr.length() == 6) {
            return colorStr;
        }
        final StringBuffer buffer = new StringBuffer(colorStr);
        while (buffer.length() < 6) {
            buffer.insert(0, '0');
        }
        return buffer.toString();
    }
    
    public static String getSystemColor(final int intColor) {
        if ((intColor & 0xFF000000) != 0xFF000000) {
            return "";
        }
        final int colorValue = intColor & 0xFFFFFF;
        return (colorValue < Html.SYS_COLOR_NAMES.length) ? Html.SYS_COLOR_NAMES[colorValue] : "";
    }
    
    @Deprecated
    public static String strToHtml(final String instring) {
        int lIndex = 0;
        if (instring == null) {
            return "";
        }
        final StringBuffer lStrbuff = new StringBuffer(instring);
        while (lIndex < lStrbuff.length()) {
            char lChar = lStrbuff.charAt(lIndex);
            if ((lChar = lStrbuff.charAt(lIndex)) == '\"') {
                lStrbuff.replace(lIndex, lIndex + 1, "&#34;");
                lIndex += 5;
            }
            else if (lChar == '&') {
                lStrbuff.replace(lIndex, lIndex + 1, "&amp;");
                lIndex += 5;
            }
            else if (lChar == '<') {
                lStrbuff.replace(lIndex, lIndex + 1, "&lt;");
                lIndex += 4;
            }
            else if (lChar == '>') {
                lStrbuff.replace(lIndex, lIndex + 1, "&gt;");
                lIndex += 4;
            }
            else if (lChar == ' ') {
                lStrbuff.replace(lIndex, lIndex + 1, "&nbsp;");
                lIndex += 6;
            }
            else {
                ++lIndex;
            }
        }
        return lStrbuff.toString();
    }
    
    public static String encodeText(final String inString) {
        if (inString == null) {
            return "";
        }
        int lIndex = 0;
        char endChar = '\0';
        final StringBuffer outString = new StringBuffer(inString);
        while (lIndex < outString.length()) {
            char lChar = outString.charAt(lIndex);
            if (lIndex + 1 < outString.length()) {
                endChar = outString.charAt(lIndex + 1);
            }
            if (lChar == '&') {
                outString.replace(lIndex, lIndex + 1, "&amp;");
                lIndex += 5;
            }
            else if (lChar == '<') {
                outString.replace(lIndex, lIndex + 1, "&lt;");
                lIndex += 4;
            }
            else if (lChar == '>') {
                outString.replace(lIndex, lIndex + 1, "&gt;");
                lIndex += 4;
            }
            else if ((lChar = outString.charAt(lIndex)) == '\"') {
                outString.replace(lIndex, lIndex + 1, "&#34;");
                lIndex += 5;
            }
            else if (lChar == '\r' && endChar == '\n') {
                outString.replace(lIndex, lIndex + 2, "<br>");
                lIndex += 4;
            }
            else if (lChar == ' ') {
                outString.replace(lIndex, lIndex + 1, "&nbsp;");
                lIndex += 6;
            }
            else {
                ++lIndex;
            }
        }
        return outString.toString();
    }
    
    @Deprecated
    public static String Double2Str(final double value) {
        final DecimalFormat df = new DecimalFormat("#.#");
        return df.format(value);
    }
    
    @Deprecated
    public static String fmtDouble(final double value) {
        final DecimalFormat df = new DecimalFormat("0.0000");
        return df.format(value);
    }
    
    public static String encodeHashMap(final HashMap hashMap) {
        if (hashMap == null || hashMap.isEmpty()) {
            return null;
        }
        final StringBuffer result = new StringBuffer();
        for (final Object key : hashMap.keySet()) {
            result.append(key);
            result.append(':');
            final Object value = hashMap.get(key);
            if (value != null) {
                result.append(value);
            }
            result.append(';');
        }
        if (result.length() > 0) {
            result.deleteCharAt(result.length() - 1);
        }
        return result.toString();
    }
    
    public static HashMap decodeHashMap(final String s) {
        if (StringUtils.isEmpty(s)) {
            return null;
        }
        final HashMap result = new HashMap();
        final String[] maps = s.split(";");
        if (maps == null) {
            return result;
        }
        for (int i = 0; i < maps.length; ++i) {
            if (!StringUtils.isEmpty(maps[i])) {
                final String[] entries = maps[i].split(":");
                if (entries != null) {
                    if (entries.length == 1) {
                        result.put(entries[0], null);
                    }
                    else if (entries.length == 2) {
                        result.put(entries[0], entries[1]);
                    }
                }
            }
        }
        return result;
    }
}
